#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2021-03-21
#
# 2024-04-18: fixed params for levels_upper (ThX to alexander[dot]laengle[at]lgt[dot]com)
#
# .1.3.6.1.4.1.15497.1.1.1.1.0 = INTEGER: 0
# .1.3.6.1.4.1.15497.1.1.1.7.0 = INTEGER: 1
#
# ASYNCOS-MAIL-MIB::perCentMemoryUtilization.0 = INTEGER: 0
# ASYNCOS-MAIL-MIB::memoryAvailabilityStatus.0 = INTEGER: memoryAvailable(1)
#
# sample info
# [[u'0', u'1']]
#

from typing import List

from cmk.base.plugins.agent_based.agent_based_api.v1.type_defs import (
    CheckResult,
    DiscoveryResult,
    HostLabelGenerator,
    StringTable,
)

from cmk.base.plugins.agent_based.agent_based_api.v1 import (
    HostLabel,
    SNMPTree,
    Service,
    check_levels,
    contains,
    register,
)


def host_label_cisco_asyncos(section: int) -> HostLabelGenerator:
    """Host label function
    Labels:
        cmk/os_family:
            This label is set to "AsyncOS" for all Cisco Ironport devices
    """
    yield HostLabel(name="cmk/os_family", value="AsyncOS")


#
# [[['48']]
#
def parse_cisco_asyncos_mem(string_table: List[StringTable]) -> int | None:
    try:
        return int(string_table[0][0][0])
    except KeyError:
        pass


def discovery_cisco_asyncos_mem(section: int) -> DiscoveryResult:
    yield Service()


def check_cisco_asyncos_mem(params, section: int) -> CheckResult:
    yield from check_levels(
        section,
        label='Memory utilization',
        levels_upper=params.get('levels', None),
        metric_name='util',
        render_func=lambda v: f'{v}%',
    )


register.snmp_section(
    name='cisco_asyncos_mem',
    parse_function=parse_cisco_asyncos_mem,
    host_label_function=host_label_cisco_asyncos,
    fetch=[
        SNMPTree(
            base='.1.3.6.1.4.1.15497.1.1.1',
            oids=[
                '1',  # perCentMemoryUtilization
            ]
        ),
    ],
    detect=contains('.1.3.6.1.2.1.1.1.0', 'AsyncOS'),
)

register.check_plugin(
    name='cisco_asyncos_mem',
    service_name='Memory utilization',
    discovery_function=discovery_cisco_asyncos_mem,
    check_function=check_cisco_asyncos_mem,
    check_default_parameters={},
    check_ruleset_name='memory'
)
