#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2024-04-18
# File  : cisco_asyncos.py (metrics)
#

from cmk.gui.i18n import _

from cmk.gui.plugins.metrics.utils import (
    metric_info,
    graph_info,
    perfometer_info
)

#
# asyncos bandwidth
#

metric_info['bandwidth_now'] = {
    'title': _('Current bandwidth'),
    'unit': 'bytes/s',
    'color': '31/a',
}

graph_info['cisco_asyncos.bandwidth_now'] = {
    'title': _('Cisco AsyncOS current bandwidth'),
    'metrics': [
        ('bandwidth_now', 'area'),
    ],
}

perfometer_info.append({
    'type': 'logarithmic',
    'metric': 'bandwidth_now',
    'half_value': 1073741824,  # 1GByte
    'exponent': 2,
})

#
# asyncos dns
#

metric_info['outstandingDNSRequests'] = {
    'title': _('Outstanding DNS requests'),
    'unit': 'count',
    'color': '31/a',
}
metric_info['pendingDNSRequests'] = {
    'title': _('Pending DNS requests'),
    'unit': 'count',
    'color': '21/a',
}
graph_info['cisco_asyncos.dns'] = {
    'title': _('Cisco AsyncOS DNS requests'),
    'metrics': [
        ('outstandingDNSRequests', 'area'),
        ('pendingDNSRequests', '-area'),
    ],
}
perfometer_info.append(('stacked', [
    {
        'type': 'logarithmic',
        'metric': 'outstandingDNSRequests',
        'half_value': 100,
        'exponent': 2,
    },
    {
        'type': 'logarithmic',
        'metric': 'pendingDNSRequests',
        'half_value': 100,
        'exponent': 2,
    }
]))

#
# asyncos message queue
#

metric_info['work_queue_size'] = {
    'title': _('Work queue size'),
    'unit': 'count',
    'color': '11/a',
}

graph_info['cisco_asyncos.queue'] = {
    'title': _('Cisco AsyncOS work queue'),
    'metrics': [
        ('work_queue_size', 'area'),
    ],
}
perfometer_info.append({
    'type': 'logarithmic',
    'metric': 'work_queue_size',
    'half_value': 100,
    'exponent': 2,
})
