#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
#
from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    TextAscii,
    Tuple,
)

from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    RulespecGroupCheckParametersNetworking,
    rulespec_registry,
)


def _parameter_valuespec_cisco_asyncos_dns():
    return Dictionary(elements=[
        ('levels_outstanding',
         Tuple(
             title=_('Upper levels for outstanding DNS requests'),
             help=_('Number of DNS requests that have been sent but for which no reply has been received.'),
             elements=[
                 Integer(title=_('Warning at'), unit=_('# of requests')),
                 Integer(title=_('Critical at'), unit=_('# of requests')),
             ])
         ),
        ('levels_pending',
         Tuple(
             title=_('Upper levels for pending DNS requests'),
             help=_('Number of DNS requests waiting to be sent.'),
             elements=[
                 Integer(title=_('Warning'), unit=_('# of requests')),
                 Integer(title=_('Critical'), unit=_('# of requests')),
             ])
         ),
    ])


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name='cisco_asyncos_dns',
        group=RulespecGroupCheckParametersNetworking,
        item_spec=lambda: TextAscii(title=_('Cisco AsyncOS DNS'), ),
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_cisco_asyncos_dns,
        title=lambda: _('Cisco AsyncOS DNS'),
    ))
