#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
#
from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    ListOfStrings,
    TextAscii,
    Tuple,
)

from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    RulespecGroupCheckParametersNetworking,
    rulespec_registry,
)


def _parameter_valuespec_cisco_asyncos_license():
    return Dictionary(elements=[
        ('features_ignore',
         ListOfStrings(
             title=_('License features to ignore'),
             orientation='vertical',
             allow_empty=False,
             # valuespec=Integer(minvalue=1, maxvalue=99),
             help=_('there will be no warning/critical if this features are expired'
                    'Examples: McAfee, IronPort Email Encryption, Data Loss Prevention, etc.'),
         )
         ),
        ('expire',
         Tuple(
             title=_('Levels for licence expiration in days'),
             elements=[
                 Integer(title=_('Warning at'), default_value=30, unit=_('days before expiration')),
                 Integer(title=_('Critical at'), default_value=7, unit=_('days before expiration')),
             ])),
    ])


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name='cisco_asyncos_license',
        group=RulespecGroupCheckParametersNetworking,
        item_spec=lambda: TextAscii(title=_('Cisco AsyncOS license'), ),
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_cisco_asyncos_license,
        title=lambda: _('Cisco AsyncOS license'),
    ))
